@@ -1,11 +1,17 @@
 import requests
 
 def is_url(path):
+    if(path is None):
+        return False
+
     if(path.startswith("https://") or path.startswith("http://")):
         return True
     return False
 
 def page_exists(url):
+    if(url is None):
+        return False
+
     request = requests.get(url)
     if request.status_code == 200:
         return True
